<?xml version="1.0" encoding="utf-8"?>
<!-- conversion from xhtml to xsl-fo, hk 2004/05/22 -->
<xsl:stylesheet 
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:fo="http://www.w3.org/1999/XSL/Format"
   xmlns:html="http://www.w3.org/1999/xhtml"
   version="1.0" >

  <xsl:template match="html:body">
      <xsl:apply-templates />
  </xsl:template>

  <!-- block elements -->

  <xsl:template match="html:p">
    <fo:block space-before="1em" space-after="0.2em">
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:p[@align='center']">
    <fo:block space-before="1em" space-after="0.2em" 
              text-align="center" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:p[@align='right']">
    <fo:block space-before="1em" space-after="0.2em" 
              text-align="right" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:li/html:p">
    <fo:block space-after="0.1em" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:li/html:p[@align='center']">
    <fo:block space-after="0.1em" 
              text-align="center" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h1" >
    <!--xsl:if test="position()&gt;2" 
      <xsl:value-of select="position()" />
      position is always 2 - ?
    --> 
    <fo:block space-before="0.5em" space-after="0.3em"
              break-before="page"
              keep-with-next.within-page="always"
              id="{generate-id(.)}"
              font-weight="bold" 
              font-size="180%" 
              line-height="200%"
              color="#C00" >
        <xsl:number count="html:body" from="html:html" level="any"
                    format="1. "/>
       <xsl:apply-templates />
    </fo:block>
    <!--/xsl:if-->
    <fo:block font-family="sans-serif" 
              line-height="180%"
              font-size="160%" 
              space-after.optimum="0.5em"
              background-color="silver"
              color="white">
       <fo:marker marker-class-name="kopf" >
         <xsl:apply-templates />
       </fo:marker>
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h2">
    <fo:block space-before="0.5em" space-after="0.2em"
              font-weight="bold" 
              font-size="160%" 
              line-height="180%"
              color="#C00" 
              keep-with-next.within-page="always" >
      <xsl:number count="html:body" from="html:html" level="any"
                    format="1."/>
      <xsl:number level="any"
                  count="html:h2" from="html:body" 
                  format="1. " />
      <xsl:apply-templates  />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h3">
    <fo:block space-before="0.5em" space-after="0.2em"
              keep-with-next.within-page="always"
              font-weight="bold" 
              font-size="140%" 
              line-height="160%"
              color="#C00" >
      <!--
      <xsl:number count="html:body" from="html:html" level="any"
                    format="1."/>
      <xsl:number level="any"
                  count="html:h2" from="html:body" 
                  format="1." />
      <xsl:number level="any"
                  count="html:h3" from="html:h2" 
                  format="1. " />
      -->
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h4">
    <fo:block space-before="0.5em" space-after="0.2em"
              keep-with-next.within-page="always"
              font-weight="bold" 
              font-size="120%" 
              line-height="140%"
              color="#C00" >
      <!--
      <xsl:number count="html:body" from="html:html" level="any"
                    format="1."/>
      <xsl:number level="any"
                  count="html:h2" from="html:body" 
                  format="1." />
      <xsl:number level="any"
                  count="html:h3" from="html:h2" 
                  format="1." />
      <xsl:number level="any"
                  count="html:h4" from="html:h3" 
                  format="1. " />
      -->
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:hr">
    <fo:block space-before="1em" space-after="1em"
              border="1px"
              width="50%"
              border-style="inset" />
  </xsl:template>

  <xsl:template match="html:pre">
    <fo:block font-family="monospace" space-before="0.5em" space-after="0.5em"
              background-color="#cfcfcf" 
              white-space-collapse="false"
              wrap-option="no-wrap"
              start-indent="0.4cm"
              text-align="left" 
              ><xsl:apply-templates />
    </fo:block>
  </xsl:template>


  <!-- inline elements -->

  <xsl:template match="html:address">
    <fo:block space-before="0.3em" space-after="0.1em" 
              font-style="italic" >
      <!--xsl:apply-templates /-->
    </fo:block>
  </xsl:template>

  <xsl:template match="html:a">
    <fo:basic-link 
        color="blue"
        external-destination="url('{@href}')" >
      <xsl:apply-templates />
    </fo:basic-link>
  </xsl:template>

  <xsl:template match="html:img">
    <fo:external-graphic 
        src="url('{@src}')" 
      ><!-- evtl. px und conditional 
        content-width="{@width}"
        content-height="{@height}" 
         -->
    </fo:external-graphic>
  </xsl:template>

  <xsl:template match="html:br">
    <fo:block />
  </xsl:template>

  <xsl:template match="html:code">
    <!-- white-space-collapse="false" -->
    <fo:inline font-family="monospace" 
               white-space-collapse="false" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:em">
    <fo:inline font-style="italic" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:strong">
    <fo:inline font-weight="bold" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>


  <!-- lists elements -->

  <xsl:template match="html:ul">
    <fo:list-block space-before="1em" space-after="0.2em" >
      <xsl:apply-templates select="html:li" />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="html:ul/html:li">
    <fo:list-item space-before="1pt" space-after="1pt" >
      <fo:list-item-label start-indent="0.4cm" end-indent="label-end()" >
        <fo:block>&#x2022;</fo:block>
      </fo:list-item-label>
      <fo:list-item-body start-indent="body-start()" >
        <fo:block space-after="0.2em" >
         <xsl:apply-templates  />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="html:ol">
    <fo:list-block space-before="1em" space-after="0.2em" >
      <xsl:apply-templates select="html:li" />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="html:ol/html:li">
    <fo:list-item space-before="1pt" space-after="1pt" >
      <fo:list-item-label start-indent="0.2cm" end-indent="label-end()" >
        <fo:block>      
           <xsl:number format="1." />
        </fo:block>
      </fo:list-item-label>
      <fo:list-item-body start-indent="body-start()" >
        <fo:block space-after="0.2em" >
         <xsl:apply-templates  />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="html:dl">
    <fo:block space-before="1em" space-after="0.5em" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:dt">
    <fo:block space-before="0.4em" space-after="1pt"
              font-weight="bold" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:dd">
    <fo:block space-before="1pt" space-after="1pt" 
              start-indent="0.5cm" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>


  <!-- table elements -->

  <xsl:template match="html:table|html:table[contains(@class,'three')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="5cm"/>
         <fo:table-column column-width="5cm"/>
         <fo:table-column column-width="5cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
  
  <xsl:template match="html:table[contains(@class,'one')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="8cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>

  <xsl:template match="html:table[contains(@class,'two')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="7cm"/>
         <fo:table-column column-width="7cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>

  <xsl:template match="html:table[contains(@class,'four')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="4cm"/>
         <fo:table-column column-width="4cm"/>
         <fo:table-column column-width="4cm"/>
         <fo:table-column column-width="4cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
  
  <xsl:template match="html:table[contains(@class,'five')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="4.2cm"/>
         <fo:table-column column-width="2.5cm"/>
         <fo:table-column column-width="2.5cm"/>
         <fo:table-column column-width="2.5cm"/>
         <fo:table-column column-width="2.5cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
  
  <xsl:template match="html:table[contains(@class,'six')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="3.5cm"/>
         <fo:table-column column-width="2cm"/>
         <fo:table-column column-width="2cm"/>
         <fo:table-column column-width="2cm"/>
         <fo:table-column column-width="2cm"/>
         <fo:table-column column-width="2cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
  
  <xsl:template match="html:table[contains(@class,'seven')]">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="#FFFFF5"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="3.2cm"/>
         <fo:table-column column-width="1.9cm"/>
         <fo:table-column column-width="1.9cm"/>
         <fo:table-column column-width="1.9cm"/>
         <fo:table-column column-width="1.9cm"/>
         <fo:table-column column-width="1.9cm"/>
         <fo:table-column column-width="1.9cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr|html:caption" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
    
  <xsl:template match="html:caption">
    <fo:table-row font-weight="bold"
        text-align="center" 
        color="#C00"
        background-color="silver"
        border-width="0"
        padding="2pt"
        >
        <fo:table-cell
            padding="2pt"
            border-width="0"
            >
          <fo:block>         
             <xsl:apply-templates />
          </fo:block>
        </fo:table-cell>
    </fo:table-row>
  </xsl:template>
  
  <xsl:template match="html:tr">
    <fo:table-row padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
       <xsl:apply-templates select="html:th|html:td"/>
    </fo:table-row>
  </xsl:template>
  
  <xsl:template match="html:th">
    <fo:table-cell font-weight="bold"
        text-align="center" 
        background-color="silver"
        padding="2pt"
        padding-start="2pt"
        border-width="1px"
        border-style="solid" >
      <fo:block>         
          <xsl:apply-templates />
      </fo:block>
    </fo:table-cell>
  </xsl:template>
  
  <xsl:template match="html:td">
    <fo:table-cell border-width="1px"
        border-style="solid" >
      <fo:block 
          padding="2pt" 
          padding-start="2pt"
          padding-left="4pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="3pt" 
          > 
      <xsl:apply-templates />
      </fo:block>
    </fo:table-cell>
  </xsl:template>
  
 
  <!-- form elements -->

  <xsl:template match="html:form">
    <fo:block space-before="1em" space-after="0.5em" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <!-- border do not work with fop 0.20.5 -->

  <xsl:template match="html:input[@type='button']">
    <fo:inline font-family="monospace" 
               background-color="silver"
               font-weight="bold"
               color="red"
               border="1px"
               border-style="inset"
               border-width="1px"
               border-top-width="1px"
               border-bottom-width="1px"
               border-left-width="1px"
               border-right-width="1px" 
               >
         Button: <xsl:value-of select="@value" />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:input[@type='text']">
    <fo:inline font-family="monospace" 
               background-color="silver"
               font-weight="bold"
               color="blue"
               border="1px"
               border-style="inset"
               border-width="1px"
               border-top-width="1px"
               border-bottom-width="1px"
               border-left-width="1px"
               border-right-width="1px" 
               >
      <xsl:text>  </xsl:text>
      Textfield: <xsl:value-of select="@value" />
      <xsl:text>  </xsl:text>
    </fo:inline>
  </xsl:template>

</xsl:stylesheet>
