<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:html="http://www.w3.org/TR/REC-html40/"
  xmlns:xlink="http://www.w3.org/1999/xlink/namespace/"
  version="1.0" >

<xsl:output encoding="ISO-8859-1" />

  <xsl:template match="book">
    <html lang="de">
      <head>
	<!-- Title entry -->
	<title><xsl:value-of select="title"/></title>
	<xsl:value-of select="authors"/>
      </head>
      <body bgcolor="white">
	<h1><xsl:value-of select="title"/></h1>
	<h2>Inhaltsverzeichnis</h2>
        <ul type="none">
	<xsl:for-each select="chapters/chapter">
          <li><xsl:value-of select="title"/>
            <ul type="none">
   	      <xsl:for-each select="section">
               <li><xsl:value-of select="title"/></li>
              </xsl:for-each>
            </ul>
          </li>
        </xsl:for-each>
	<xsl:for-each select="appendices/appendix">
          <li>Anhang <xsl:value-of select="title"/></li>
        </xsl:for-each>
        </ul>
	<xsl:apply-templates select="overview"/>
	<xsl:apply-templates select="chapters"/>
	<xsl:apply-templates select="appendices"/>
	<xsl:apply-templates select="bibliography"/>
      </body>
    </html>
  </xsl:template>
  
    <xsl:template match="strong">
    <strong>
      <xsl:apply-templates/>
    </strong>
    </xsl:template>
    
    <xsl:template match="bf">
    <b>
      <xsl:apply-templates/>
    </b>
    </xsl:template>
    
    <xsl:template match="it">
    <it>
      <xsl:apply-templates/>
    </it>
    </xsl:template>
    
    <xsl:template match="tt">
    <tt>
      <xsl:apply-templates/>
    </tt>
    </xsl:template>
    
    <xsl:template match="em">
    <em>
      <xsl:apply-templates/>
    </em>
    </xsl:template>
    
    <xsl:template match="code">
    <pre>
      <xsl:apply-templates/>
    </pre>
    </xsl:template>
    
    <xsl:template match="var">
    <it>
      <xsl:apply-templates/>
    </it>
    </xsl:template>

    <xsl:template match="newpage">
    <p> </p>
    </xsl:template>    

    <xsl:template match="list/item">
    <li>
      <xsl:apply-templates/>
    </li>
    </xsl:template>

    <xsl:template match="list[type='unordered']">
    <ul>
      <xsl:apply-templates/>
    </ul>
    </xsl:template>

    <xsl:template match="list[type='ordered']">
    <ol>
      <xsl:apply-templates/>
    </ol>
    </xsl:template>
    
    <xsl:template match="quote">
    <blockquote>
      <xsl:apply-templates/>
    </blockquote>
    </xsl:template>
      
    <xsl:template match="note">
      <p align="justify"><strong>Bemerkung: </strong> <em>
      <xsl:apply-templates/>
	  </em></p>
    </xsl:template>
      
    <xsl:template match="warning">
      <p align="justify"><em>Warnung: </em> <strong>
      <xsl:apply-templates/>
	  </strong></p>
    </xsl:template>
      
    <xsl:template match="list/item/list/item">
    <li>
      <xsl:apply-templates/>
    </li>
    </xsl:template>

    <xsl:template match="overview">
      <h2><xsl:apply-templates select="title"/></h2>
      <xsl:apply-templates select="paragraph"/>
    </xsl:template>

    <xsl:template match="paragraph">
      <p><xsl:apply-templates/></p>
    </xsl:template>

    <xsl:template match="chapters">
      <xsl:for-each select="chapter">
      <xsl:apply-templates/>
      </xsl:for-each>
    </xsl:template>

    <xsl:template match="appendices">
      <xsl:for-each select="appendix">
      <xsl:apply-templates/>
      </xsl:for-each>
    </xsl:template>

    <xsl:template match="chapter|appendix">
      <xsl:apply-templates select="title"/>
      <xsl:for-each select="paragraph">
      <xsl:apply-templates/>
      </xsl:for-each>
      <xsl:for-each select="section">
      <xsl:apply-templates/>
      </xsl:for-each>
    </xsl:template>

    <xsl:template match="chapter/title">
      <h2>
      <xsl:number count="chapter" from="chapters" level="any"/><xsl:text>. </xsl:text><xsl:apply-templates/>
      </h2>
    </xsl:template>

    <xsl:template match="section/title">
    <h3>
      <xsl:number level="multiple"
	count="chapter|section"
	format="1.1. "/>
      <xsl:apply-templates/>
    </h3>
    </xsl:template>

    <xsl:template match="section/section/title">
    <h3>
      <xsl:apply-templates/>
    </h3>
    </xsl:template>

    <xsl:template match="section/section/section/title">
      <h4>
      <xsl:apply-templates/>
      </h4>
    </xsl:template>

    <xsl:template match="appendix/title">
      <h2>
      <xsl:text>Anhang </xsl:text>
      <xsl:number level="multiple" from="appendices" count="appendix" 
                  format="A. "/><xsl:apply-templates/>
      </h2>
    </xsl:template>

    <xsl:template match="book/authors">
      <xsl:apply-templates/>
    </xsl:template>

    <!--xsl:template match="/book/authors">
      <xsl:apply-templates select="author"/>
    </xsl:template-->

    <xsl:template match="book/authors/author">
      <xsl:value-of select="."/>
      <!--meta lang="de" name="Author" content="{.}"/-->
    </xsl:template>

    <xsl:template match="img">
      <img alt="{title}" src="{xlink:href}.gif"/>
    </xsl:template>

    <xsl:template match="manager">
       <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="organisation">
       <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography">
      <h2>Literatur</h2>
      <ol>
      <xsl:for-each select="entry">
      <li>
      <xsl:apply-templates select="authors"/>,
      <em><xsl:apply-templates select="title"/></em>,
      <strong><xsl:apply-templates select="year"/></strong>,
      <xsl:apply-templates select="publisher"/>
      </li>
      </xsl:for-each>
      </ol>
    </xsl:template>

    <xsl:template match="entry/authors">
      <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="link">
       <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="@xlink:href">
       href={xlink:href}
    </xsl:template>

    <xsl:template match="entry/authors/author">
      <a alt="{.}" href="{xlink:href}">
      <xsl:value-of select="."/>
      </a>
    </xsl:template>

</xsl:stylesheet>
